@@ -8,7 +8,7 @@ extern char **sequences;
                       Begin Function prototypes                       */
 
 double mychisq(int c,int d, int WH);
-int diff(int seq1, int seq2, int *range, int *polyposn);
+static int diff(int seq1, int seq2, int *range, int *polyposn);
 double getMaxChi(int *polyposn, int nsites, int winHalfWidth); 
 void doChi(int *polyposn, int nsites, int winHalfWidth, double nullquant,
 		      int maxnum, int *numsigOut, double *chisqsOut, 
